<?php

namespace Litecms\Enquiry\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Enquiry\Models\Cost;


class CostAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Cost $cost, array $request = [])
    {
        $this->model = $cost;

        $function = Str::camel($action);
        event('litecms.enquiry.cost.action.' . $action . 'ing', [$cost]);
        $data =  $this->$function($cost, $request);
        event('litecms.enquiry.cost.action.' . $action . 'ed', [$cost]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Cost $cost, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $cost = $cost->create($attributes);
        return $cost;
    }

    public function update(Cost $cost, array $request)
    {
        $attributes = $request;
        $cost->update($attributes);
        return $cost;
    }

    public function delete(Cost $cost, array $request)
    {
        $cost->delete();
        return $cost;
    }

    public function copy(Cost $cost, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $cost = $cost->replicate();
            $cost->created_at = Carbon::now();
            $cost->save();
            return $cost;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $cost->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $cost;
    }


}
