<?php

namespace Litecms\Enquiry\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Enquiry\Models\Enquiry;


class EnquiryAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Enquiry $enquiry, array $request = [])
    {
        $this->model = $enquiry;

        $function = Str::camel($action);
        event('litecms.enquiry.enquiry.action.' . $action . 'ing', [$enquiry]);
        $data =  $this->$function($enquiry, $request);
        event('litecms.enquiry.enquiry.action.' . $action . 'ed', [$enquiry]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Enquiry $enquiry, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $enquiry = $enquiry->create($attributes);
        return $enquiry;
    }

    public function update(Enquiry $enquiry, array $request)
    {
        $attributes = $request;
        $enquiry->update($attributes);
        return $enquiry;
    }

    public function delete(Enquiry $enquiry, array $request)
    {
        $enquiry->delete();
        return $enquiry;
    }

    public function copy(Enquiry $enquiry, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $enquiry = $enquiry->replicate();
            $enquiry->created_at = Carbon::now();
            $enquiry->save();
            return $enquiry;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $enquiry->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $enquiry;
    }


}
