<?php

namespace Litecms\Enquiry\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Enquiry\Actions\CostAction;
use Litecms\Enquiry\Http\Requests\CostActionRequest;
use Litecms\Enquiry\Http\Resources\CostResource;
use Litecms\Enquiry\Models\Cost;

/**
 * Admin web controller class.
 */
class CostActionController extends BaseController
{

    /**
     * Action controller function for cost.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CostActionRequest $request, Cost $cost, $action)
    {
        try {
            $request = $request->all();
            $cost = CostAction::run($action, $cost, $request);

            $data = new CostResource($cost);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('enquiry::cost.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('enquiry/cost/' . $cost->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('enquiry/cost/' . $cost->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
