<?php

namespace Litecms\Enquiry\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Enquiry\Http\Requests\CostActionsRequest;
use Litecms\Enquiry\Models\CostActions;

/**
 * Admin web controller class.
 */
class CostActionsController extends BaseController
{

    /**
     * Action controller function for cost.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CostActionsRequest $request, $action)
    {
        try {
            $cost = CostActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('enquiry::cost.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('enquiry/cost/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('enquiry/cost/' . $action))
                ->redirect();
        }
    }
}
