<?php

namespace Litecms\Enquiry\Http\Controllers;

use Exception;
use Litecms\Enquiry\Actions\CostWorkflow;
use Litecms\Enquiry\Http\Requests\CostWorkflowRequest;
use Litecms\Enquiry\Http\Resources\CostResource;
use Litecms\Enquiry\Models\Cost;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class CostWorkflowController extends BaseController
{
    /**
     * Action controller function for cost.
     *
     * @param Model $cost
     * @param action next action for the cost.
     *
     * @return Response
     */
    public function __invoke(CostWorkflowRequest $request, Cost $cost, $trasition)
    {
        try {
            $request = $request->all();
            $cost = CostWorkflow::run($trasition, $cost, $request);
            $data = new CostResource($cost);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('enquiry::cost.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('enquiry/cost/' . $cost->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('enquiry/cost/' . $cost->getRouteKey()))
                ->redirect();
        }
    }
}
