<?php

namespace Litecms\Enquiry\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Enquiry\Actions\EnquiryAction;
use Litecms\Enquiry\Http\Requests\EnquiryActionRequest;
use Litecms\Enquiry\Http\Resources\EnquiryResource;
use Litecms\Enquiry\Models\Enquiry;

/**
 * Admin web controller class.
 */
class EnquiryActionController extends BaseController
{

    /**
     * Action controller function for enquiry.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(EnquiryActionRequest $request, Enquiry $enquiry, $action)
    {
        try {
            $enquiry = EnquiryAction::run($request, $enquiry, $action);

            $data = new EnquiryResource($enquiry);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('enquiry::enquiry.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('enquiry/enquiry/' . $enquiry->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('enquiry/enquiry/' . $enquiry->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
