<?php

namespace Litecms\Enquiry\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litecms\Enquiry\Actions\EnquiryExim;
use Litecms\Enquiry\Http\Requests\EnquiryEximRequest;

/**
 * Admin web controller class.
 */
class EnquiryEximController extends BaseController
{
    /**
     * Action controller function for enquiry.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(EnquiryEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = EnquiryExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('enquiry:enquiry.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('enquiry/enquiry/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('enquiry/enquiry/' . $exim))
                ->redirect();
        }
    }
}
