<?php

namespace Litecms\Enquiry\Http\Controllers;

use Exception;
use Litecms\Enquiry\Actions\EnquiryWorkflow;
use Litecms\Enquiry\Http\Requests\EnquiryWorkflowRequest;
use Litecms\Enquiry\Http\Resources\EnquiryResource;
use Litecms\Enquiry\Models\Enquiry;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class EnquiryWorkflowController extends BaseController
{
    /**
     * Action controller function for enquiry.
     *
     * @param Model $enquiry
     * @param action next action for the enquiry.
     *
     * @return Response
     */
    public function __invoke(EnquiryWorkflowRequest $request, Enquiry $enquiry, $trasition)
    {
        try {
            $request = $request->all();
            $enquiry = EnquiryWorkflow::run($trasition, $enquiry, $request);
            $data = new EnquiryResource($enquiry);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('enquiry::enquiry.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('enquiry/enquiry/' . $enquiry->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('enquiry/enquiry/' . $enquiry->getRouteKey()))
                ->redirect();
        }
    }
}
