<?php

namespace Litecms\Enquiry\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Enquiry\Events\CostWorkflow as CostWorkflowEvent;
use Litecms\Enquiry\Notifications\CostWorkflow as CostWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CostWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CostWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $cost is submitted.
     *
     * @param CostWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CostWorkflowEvent $event)
    {
        $client = $event->$cost->client;
        Notification::send($client, new CostWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $cost is published.
     *
     * @param CostWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CostWorkflowEvent $event)
    {
        $client = $event->$cost->client;
        Notification::send($client, new CostWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $cost is approved.
     *
     * @param CostWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CostWorkflowEvent $event)
    {
        $client = $event->$cost->client;
        Notification::send($client, new CostWorkflowNotification($event));
    }

    /**
     * Handles the $cost workflow event as a listener.
     *
     * @param CostWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CostWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
