<?php

namespace Litecms\Enquiry\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Enquiry\Events\EnquiryWorkflow as EnquiryWorkflowEvent;
use Litecms\Enquiry\Notifications\EnquiryWorkflow as EnquiryWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class EnquiryWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(EnquiryWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $enquiry is submitted.
     *
     * @param EnquiryWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(EnquiryWorkflowEvent $event)
    {
        $client = $event->$enquiry->client;
        Notification::send($client, new EnquiryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $enquiry is published.
     *
     * @param EnquiryWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(EnquiryWorkflowEvent $event)
    {
        $client = $event->$enquiry->client;
        Notification::send($client, new EnquiryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $enquiry is approved.
     *
     * @param EnquiryWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(EnquiryWorkflowEvent $event)
    {
        $client = $event->$enquiry->client;
        Notification::send($client, new EnquiryWorkflowNotification($event));
    }

    /**
     * Handles the $enquiry workflow event as a listener.
     *
     * @param EnquiryWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(EnquiryWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
