<?php
namespace Litecms\Enquiry\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Enquiry\Events\EnquiryAction as EnquiryActionEvent;
use Litecms\Enquiry\Models\Enquiry;

class EnquiryAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $enquiry;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param EnquiryActionEvent $enquiry
     * @param string $action
     */
    public function __construct(EnquiryActionEvent $enquiry, string $action)
    {
        $this->action = $action;
        $this->enquiry = $enquiry;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Enquiry Approved - ' . config('app.name'))
            ->view('enquiry::enquiry.email.action', ['data' => $this->enquiry]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
