<?php

namespace Litecms\Enquiry\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Enquiry\Models\Cost;

class CostPolicy
{

    use CostAction;
    use CostReport;
    use CostWorkflow;

    /**
     * Determine if the given user can view the cost.
     *
     * @param UserPolicyInterface $authUser
     * @param Cost $cost
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Cost $cost)
    {
        if ($authUser->canDo('enquiry.cost.view') && $authUser->isAdmin()) {
            return true;
        }

        return $cost->user_id == user_id() && $cost->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cost.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('enquiry.cost.create');
    }

    /**
     * Determine if the given user can update the given cost.
     *
     * @param UserPolicyInterface $authUser
     * @param Cost $cost
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Cost $cost)
    {
        if ($authUser->canDo('enquiry.cost.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $cost->user_id == user_id() && $cost->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cost.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Cost $cost)
    {
        return $cost->user_id == user_id() && $cost->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cost.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Cost $cost)
    {
        if ($authUser->canDo('enquiry.cost.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cost.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Cost $cost)
    {
        if ($authUser->canDo('enquiry.cost.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
