<?php

namespace Litecms\Enquiry\Policies;

use Litecms\Enquiry\Models\Enquiry;
use Litepie\User\Interfaces\UserPolicyInterface;

trait EnquiryAction
{

    /**
     * Determine if the given user can approve the given enquiry.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Enquiry $enquiry)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('enquiry.enquiry.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given enquiry.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Enquiry $enquiry) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('enquiry.enquiry.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given enquiry.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Enquiry $enquiry)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('enquiry.enquiry.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given enquiry.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Enquiry $enquiry)
    {


        if ($authUser->canDo('enquiry.enquiry.action.delete')) {
            return true;
        }

        return false;
    }


}
