<?php

namespace Litecms\Enquiry\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Enquiry\Models\Enquiry;

class EnquiryPolicy
{

    use EnquiryAction;
    use EnquiryExim;
    use EnquiryReport;
    use EnquiryWorkflow;

    /**
     * Determine if the given user can view the enquiry.
     *
     * @param UserPolicyInterface $authUser
     * @param Enquiry $enquiry
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Enquiry $enquiry)
    {
        if ($authUser->canDo('enquiry.enquiry.view') && $authUser->isAdmin()) {
            return true;
        }

        return $enquiry->user_id == user_id() && $enquiry->user_type == user_type();
    }

    /**
     * Determine if the given user can create a enquiry.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('enquiry.enquiry.create');
    }

    /**
     * Determine if the given user can update the given enquiry.
     *
     * @param UserPolicyInterface $authUser
     * @param Enquiry $enquiry
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Enquiry $enquiry)
    {
        if ($authUser->canDo('enquiry.enquiry.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $enquiry->user_id == user_id() && $enquiry->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given enquiry.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Enquiry $enquiry)
    {
        return $enquiry->user_id == user_id() && $enquiry->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given enquiry.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Enquiry $enquiry)
    {
        if ($authUser->canDo('enquiry.enquiry.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given enquiry.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Enquiry $enquiry)
    {
        if ($authUser->canDo('enquiry.enquiry.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
